function [So,codigo]=generaSo(M,B,s)

% parametros entrada:
%       M= nro de de portadoras,es decir,nro de bits por simbolo OFDM
%       B= nro de simbolos que transmitiremos a la vez
%       s= simbolo o simbolos a ttir
% parametros salida:
%       So=es el vector fila (Mx1) que usaremos como señal ttida.


if B==1                    % solo ttito un simbolo
    %matrizcodigos=hadamard(M);
    %c=matrizcodigos(:,1); %me quedo con un codigo de la matriz (por ejemplo 
    c=sign(randn(M,1))/sqrt(length(c));
    codigo=c;
    So=c*s;                      %la primera columna)
                          
    
    
    
    
else                       %ttito B simbolos simultaneamente

    matrizcodigos=hadamard(M/B);
    c=matrizcodigos(:,1);   
    I=eye(B);
    C=kron(I,c);     
    So=C*s;

end